#ifndef __OUTPUT_H
#define __OUTPUT_H

#define OUT_TYPE_MOUSE 	0
#define OUT_TYPE_KEY	1
#define OUT_TYPE_TCP	2
#define OUT_TYPE_EXE    3

int output_init();
int output_gui_init();
void output_gui_update(int type);
void output_set_type(int type);

#endif
