#ifndef __GSTREAMER_H
#define __GSTREAMER_H

#include "source.h"

void            gstr_source_free(struct video_src *source);
int             gstr_source_init(struct video_src *source);
void            gstr_capture_start(struct video_src *source);
void            gstr_capture_stop(struct video_src *source);
int             gstr_gui_init();
gboolean        cb_gstr_frame_received(GstElement * element, GstBuffer * buffer,
                               GstPad * pad, struct video_src *source);    
gboolean        gstr_pipeline_is_valid(gchar * pipeline);
                               
#endif
