#ifndef __PREFS_H
#define __PREFS_H

#include <libxml/xmlmemory.h>
#include <libxml/parser.h>
#include <libxml/parserInternals.h>


#define PREFS_VERSION "0.3" /* xml dtd version */

int prefs_init(int argc, char *argv[]);
void prefs_cleanup();
int prefs_gui_init();
xmlNodePtr prefs_xmlNode_find(char *nodeName, xmlDocPtr doc, xmlNode * node);
xmlDocPtr prefs_get_xmlDoc();
void prefs_set_quiet(int q);
int prefs_get_quiet();
void prefs_set_verbose(int v);
int prefs_get_verbose();

#endif
