
#ifndef __MAIN_H
#define __MAIN_H

/* SVN Revision from autoconf-script */
#ifndef REVISION
#define REVISION "UNKNOWN"
#endif

/* Builddate stub */
#ifndef BUILDDATE
#define BUILDDATE "unknown"
#endif


/* macros */
#define _ERROR if(!prefs_get_quiet())
#define _VERBOSE1 if(prefs_get_verbose() >= 1)
#define _VERBOSE2 if(prefs_get_verbose() >= 2)
#define _VERBOSE3 if(prefs_get_verbose() >= 3)
#define _VERBOSE4 if(prefs_get_verbose() >= 4)
#define _VERBOSE5 if(prefs_get_verbose() >= 5)
#define _VERBOSE6 if(prefs_get_verbose() >= 6)
    
#endif
