
#ifndef __GFX_H
#define __GFX_H


void            g_warp_image(unsigned char *src, unsigned char *dest,
                                int dst_width, int dst_height,
                                int x1, int y1, int x2, int y2, 
                                int x3, int y3, int x4, int y4);
void            g_threshold_frame(unsigned char *src, unsigned char *dst, int size,
                                double threshold, unsigned char R, 
                                unsigned char G, unsigned char B);
void            g_track_xy(unsigned char *data, struct video_src *source,
                                struct sensor *current_sensor);
                                    
                                
#endif
