
#ifndef __X11_H
#define __X11_H

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/extensions/XTest.h>
#define XK_LATIN1
#define XK_MISCELLANY
#define XK_XKB_KEYS
#include <X11/keysymdef.h>


int             x_init();
void            x_warp(int x, int y);
void            x_keyPress(KeySym key);
void            x_click(int pressed, int buttonmask);
void            x_flush();

#endif
