
#ifndef __WARP_H
#define __WARP_H

int warp_gui_init();
void warp_gui_update();
void warp_image(unsigned char *src, unsigned char *dest,
                int dst_width, int dst_height,
                int x1, int y1, int x2, int y2,
                int x3, int y3, int x4, int y4);
#endif
