#ifndef __PREFS_H
#define __PREFS_H

#include <libxml/xmlmemory.h>
#include <libxml/parser.h>
#include <libxml/parserInternals.h>


int             prefs_get_verbose();
int             prefs_get_quiet();
xmlDocPtr       prefs_get_xml();
void            prefs_set_verbose(int v);
void            prefs_set_quiet(int q);
int             prefs_init();
int             prefs_config_init();
void            prefs_cleanup();
void            prefs_parse_arguments(int argc, char *argv[]);    
xmlNodePtr      get_xml_node(char *nodeName, xmlDocPtr doc, xmlNode * node);

#endif
