#ifndef __GFX_H
#define __GFX_H

#define SPOT_MIN_WIDTH 0
#define SPOT_MIN_HEIGHT 0


void        g_track_xy(unsigned char *data);
void        g_drawBox_invert(unsigned char *data, int pix_width,
                                        int x, int y, int width, int height);
void        g_drawLine_invert(unsigned char *buffer, 
                                        int width, int height,
                                        register int x1, register int y1,
                                        register int x2, register int y2);
void        g_drawBox(unsigned char *data, int pix_width, int x, int y,
                                        int width, int height);


#endif
