
#ifndef __THRESH_H
#define __THRESH_H

int thresh_gui_init();
void thresh_gui_update();
gboolean thresh_get_do();
void thresh_set_do(gboolean t);
void thresh_frame(unsigned char *src, unsigned char *dst,
                     int size, double threshold, unsigned char R,
                     unsigned char G, unsigned char B);
                     
#endif
