#ifndef __GUI_H
#define __GUI_H

#include <libxml/xmlmemory.h>
#include <libxml/parser.h>
#include <libxml/parserInternals.h>
#include <glade/glade.h>

GladeXML *gui_get_xml();
GtkWidget *gui_get_da_dst();
GtkWidget *gui_get_da_src();
GtkWidget *gui_get_capTextView();
void gui_set_capTextView(GtkWidget *w);
char *gui_get_gladefile();
void gui_set_gladefile(char *name);
int gui_init();
void gui_cleanup();
void gui_dialog(const char *fmt, ...);
    
#endif
